#-------------------------------------------------------------------------------
# @(#) ericsson-utran/p5_perf/UserConfig.pm ericsson-utran_d3.3.1.latest:cset.003188:4:4@(#)
#-------------------------------------------------------------------------------
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
#
# Ericsson UTRAN P5 - Performance data, post parser processing. 
#
# (c) Copyright IBM Corporation, 2007. All rights reserved.
#
package UserConfig;


@ISA = qw(Exporter);
@EXPORT = qw(postparser_config);

use strict;
use Exporter ();

#-------------------------------------------------------------------------------

my @rules = (

# START : IMA_GROUP
# Unpegger for IMA_GROUP NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IMA_GROUP NodeB Counters',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_IMA_GROUP-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^NODEB_IMA_GROUP-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_ImaGroup' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 'True',
	#OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmGrFc' => 4294967295,
	     'pmGrFcFe' => 4294967295,
	     'pmGrUasIma' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IMA_GROUP NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IMA_GROUP NodeB PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_IMA_GROUP-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for IMA_GROUP RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IMA_GROUP RNC Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_IMA_GROUP-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_IMA_GROUP-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_ImaGroup' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmGrFc' => 4294967295,
	     'pmGrFcFe' => 4294967295,
	     'pmGrUasIma' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IMA_GROUP RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IMA_GROUP RNC PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_IMA_GROUP-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for IMA_GROUP RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IMA_GROUP RXI Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_IMA_GROUP-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RXI_IMA_GROUP-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_ImaGroup' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmGrFc' => 4294967295,
	     'pmGrFcFe' => 4294967295,
	     'pmGrUasIma' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IMA_GROUP RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IMA_GROUP RXI PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_IMA_GROUP-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : IMA_GROUP

# START : IMA_LINK
# Unpegger for IMA_LINK NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IMA_LINK NodeB Counters',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_IMA_LINK-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^NODEB_IMA_LINK-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_ImaGroup','moid_ImaLink' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 'True',
	#OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmIvIma' => 4294967295,
	     'pmOifIma' => 4294967295,
	     'pmRxFc' => 4294967295,
	     'pmRxFcFe' => 4294967295,
	     'pmRxStuffIma' => 4294967295,
	     'pmRxUusIma' => 4294967295,
	     'pmRxUusImaFe' => 4294967295,
	     'pmSesIma' => 4294967295,
	     'pmSesImaFe' => 4294967295,
	     'pmTxFc' => 4294967295,
	     'pmTxFcFe' => 4294967295,
	     'pmTxStuffIma' => 4294967295,
	     'pmTxUusIma' => 4294967295,
	     'pmTxUusImaFe' => 4294967295,
	     'pmUasIma' => 4294967295,
	     'pmUasImaFe' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IMA_LINK NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IMA_LINK NodeB PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_IMA_GROUP-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for IMA_LINK RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IMA_LINK RNC Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_IMA_LINK-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_IMA_LINK-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_ImaGroup','moid_ImaLink' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmIvIma' => 4294967295,
	     'pmOifIma' => 4294967295,
	     'pmRxFc' => 4294967295,
	     'pmRxFcFe' => 4294967295,
	     'pmRxStuffIma' => 4294967295,
	     'pmRxUusIma' => 4294967295,
	     'pmRxUusImaFe' => 4294967295,
	     'pmSesIma' => 4294967295,
	     'pmSesImaFe' => 4294967295,
	     'pmTxFc' => 4294967295,
	     'pmTxFcFe' => 4294967295,
	     'pmTxStuffIma' => 4294967295,
	     'pmTxUusIma' => 4294967295,
	     'pmTxUusImaFe' => 4294967295,
	     'pmUasIma' => 4294967295,
	     'pmUasImaFe' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IMA_LINK RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IMA_LINK RNC PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_IMA_LINK-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for IMA_LINK RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IMA_LINK RXI Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_IMA_LINK-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RXI_IMA_LINK-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_ImaGroup','moid_ImaLink' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmIvIma' => 4294967295,
	     'pmOifIma' => 4294967295,
	     'pmRxFc' => 4294967295,
	     'pmRxFcFe' => 4294967295,
	     'pmRxStuffIma' => 4294967295,
	     'pmRxUusIma' => 4294967295,
	     'pmRxUusImaFe' => 4294967295,
	     'pmSesIma' => 4294967295,
	     'pmSesImaFe' => 4294967295,
	     'pmTxFc' => 4294967295,
	     'pmTxFcFe' => 4294967295,
	     'pmTxStuffIma' => 4294967295,
	     'pmTxUusIma' => 4294967295,
	     'pmTxUusImaFe' => 4294967295,
	     'pmUasIma' => 4294967295,
	     'pmUasImaFe' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IMA_LINK RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IMA_LINK RXI PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_IMA_LINK-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : IMA_LINK

# START : ME_TN_Mtp3bSpItu_Mtp3bAp
# Unpegger for ME_TN_Mtp3bSpItu_Mtp3bAp
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg ME_TN_Mtp3bSpItu_Mtp3bAp Counters',
	INPUT_FILE_DESCRIPTION	   => '^(ME_TN_Mtp3bSpItu_Mtp3bAp-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^ME_TN_Mtp3bSpItu_Mtp3bAp-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Mtp3bSpItu','moid_Mtp3bAp' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfAdjacentSPNotAccessible' => 4294967295,
	     'pmNoOfUserPartUnavailRec' => 4294967295,
        },
},
# Remove initial PIF after unpegger for ME_TN_Mtp3bSpItu_Mtp3bAp
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ME_TN_Mtp3bSpItu_Mtp3bAp PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(ME_TN_Mtp3bSpItu_Mtp3bAp-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : ME_TN_Mtp3bSpItu_Mtp3bAp

# START : ME_TN_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu
# Unpegger for ME_TN_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg ME_TN_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu Counters',
	INPUT_FILE_DESCRIPTION	   => '^(ME_TN_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^ME_TN_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Mtp3bSpItu','moid_Mtp3bSlItu','moid_Mtp3bSls' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfMSURec' => 4294967295,
	     'pmNoOfMSUSent' => 4294967295,
	     'pmNoOfAALINServiceInd' => 4294967295,
	     'pmNoOfAALOUTInd' => 4294967295,
	     'pmNoOfCBDSent' => 4294967295,
	     'pmNoOfCOOXCOSent' => 4294967295,
	     'pmNoOfLocalLinkCongestCeaseRec' => 4294967295,
	     'pmNoOfLocalLinkCongestRec' => 4294967295,
        },
},
# Remove initial PIF after unpegger for ME_TN_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ME_TN_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(ME_TN_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : ME_TN_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu

# START : RNC_Mtp3bSpItu_Signaling
# Unpegger for RNC_Mtp3bSpItu_Signaling
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg RNC_Mtp3bSpItu_Signaling Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Mtp3bSpItu_Signaling-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_Mtp3bSpItu_Signaling-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Mtp3bSpItu' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfECARec' => 4294967295,
	     'pmNoOfECASent' => 4294967295,
	     'pmNoOfECOSent' => 4294967295,
	     'pmNoOfEmergencyChangeOverRec' => 4294967295,
	     'pmNoOfLowerPrioMsgDiscarded' => 4294967295,
	     'pmNoOfForcedRerouteSuccessPerf' => 4294967295,
	     'pmNoOfCBARec' => 4294967295,
	     'pmNoOfCBASent' => 4294967295,
	     'pmNoOfChangeBackDeclRec' => 4294967295,
	     'pmNoOfChangeOverRec' => 4294967295,
	     'pmNoOfCOAXCARec' => 4294967295,
	     'pmNoOfCOAXCASent' => 4294967295,
	     'pmNoOfControlledRerouteSuccessPerf' => 4294967295,
	     'pmNoOfInAssEstReqStDownStEstBl' => 4294967295,
	     'pmNoOfMaxTrialsForAssocActivReached' => 4294967295,
	     'pmNoOfMaxTrialsForAssocEstabReached' => 4294967295,
	     'pmNoOfSctpAssociationRestart' => 4294967295,
	     'pmNoOfSctpBufOverflow' => 4294967295,
	     'pmNoOfSctpCommunicationErr' => 4294967295,
	     'pmNoOfSctpNetworkStatusChange' => 4294967295,
	     'pmNoOfSctpResumeSending' => 4294967295,
	     'pmNoOfSctpSendFailure' => 4294967295,
	     'pmNoOfSLTAFirstTimeOutRec' => 4294967295,
	     'pmNoOfSLTASecondTimeOutRec' => 4294967295,
	     'pmNoOfSuccessAssocAbort' => 4294967295,
	     'pmNoOfSuccessAssocEstablish' => 4294967295,
	     'pmNoOfSuccessAssocShutDown' => 4294967295,
	     'pmNoOfTimerT21WasStarted' => 4294967295,
	     'pmNoOfTRARec' => 4294967295,
	     'pmNoOfTRASent' => 4294967295,
	     'pmNoOfUnsuccessAssocAbort' => 4294967295,
	     'pmNoOfUnsuccessAssocEstablish' => 4294967295,
	     'pmNoOfUnsuccessAssocShutDown' => 4294967295,
	     'pmNoOfUnsuccessControlledRerouting' => 4294967295,
	     'pmNoOfUnsuccessForcedRerouting' => 4294967295,
	     'pmNoOfUPMsgDiscardedDueToRoutingErr' => 4294967295,
        },
},
# Remove initial PIF after unpegger for RNC_Mtp3bSpItu_Signaling
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial RNC_Mtp3bSpItu_Signaling PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Mtp3bSpItu_Signaling-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : RNC_Mtp3bSpItu_Signaling

# START : ME_TN_Mtp3bSpItu_Mtp3bSrs_Mtp3bSr
# Unpegger for ME_TN_Mtp3bSpItu_Mtp3bSrs_Mtp3bSr
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg ME_TN_Mtp3bSpItu_Mtp3bSrs_Mtp3bSr Counters',
	INPUT_FILE_DESCRIPTION	   => '^(ME_TN_Mtp3bSpItu_Mtp3bSrs_Mtp3bSr-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^ME_TN_Mtp3bSpItu_Mtp3bSrs_Mtp3bSr-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Mtp3bSpItu','moid_Mtp3bSrs', 'moid_Mtp3bSr' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfSecondsAccumulatedRouteUnavailable' => 4294967295,
        },
},
# Remove initial PIF after unpegger for ME_TN_Mtp3bSpItu_Mtp3bSrs_Mtp3bSr
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ME_TN_Mtp3bSpItu_Mtp3bSrs_Mtp3bSr PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(ME_TN_Mtp3bSpItu_Mtp3bSrs_Mtp3bSr-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : ME_TN_Mtp3bSpItu_Mtp3bSrs_Mtp3bSr

# START : ME_TN_Mtp3bSpItu_Mtp3bSrs
# Unpegger for ME_TN_Mtp3bSpItu_Mtp3bSrs
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg ME_TN_Mtp3bSpItu_Mtp3bSrs Counters',
	INPUT_FILE_DESCRIPTION	   => '^(ME_TN_Mtp3bSpItu_Mtp3bSrs-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^ME_TN_Mtp3bSpItu_Mtp3bSrs-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Mtp3bSpItu','moid_Mtp3bSrs' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfDiscardedMsgFromBroadToNarrow' => 4294967295,
	     'pmNoOfTransferAllowedRec' => 4294967295,
	     'pmNoOfTransferControlledRec' => 4294967295,
	     'pmNoOfTransferProhibitedRec' => 4294967295,
        },
},
# Remove initial PIF after unpegger for ME_TN_Mtp3bSpItu_Mtp3bSrs
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ME_TN_Mtp3bSpItu_Mtp3bSrs PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(ME_TN_Mtp3bSpItu_Mtp3bSrs-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : ME_TN_Mtp3bSpItu_Mtp3bSrs

# START : RNC_Signaling_Connection_Control
# Unpegger for RNC_Signaling_Connection_Control
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg RNC_Signaling_Connection_Control Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Signaling_Connection_Control-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_Signaling_Connection_Control-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_SccpSp','moid_SccpScrc' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfConnectFailure' => 4294967295,
	     'pmNoOfRoutingFailSubsysUnavail' => 4294967295,
	     'pmNoOfRoutingFailure' => 4294967295,
	     'pmNoOfHopCounterViolation' => 4294967295,
	     'pmNoOfRoutingFailNetworkCongest' => 4294967295,
	     'pmNoOfRoutingFailNoTransAddrOfSuchNature' => 4294967295,
	     'pmNoOfRoutingFailNoTransSpecificAddr' => 4294967295,
	     'pmNoOfRoutingFailReasonUnknown' => 4294967295,
	     'pmNoOfRoutingFailUnequippedSubsys' => 4294967295,
	     'pmNoOfRoutingFailurePointCodeUnAvail' => 4294967295,
        },
},
# Remove initial PIF after unpegger for RNC_Signaling_Connection_Control
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ME_TN_Mtp3bSpItu_Mtp3bSrs PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Signaling_Connection_Control-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : RNC_Signaling_Connection_Control

# START : RNC_Signaling_Connection_Control_SccpSp
# Unpegger for RNC_Signaling_Connection_Control_SccpSp
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg RNC_Signaling_Connection_Control_SccpSp Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Signaling_Connection_Control_SccpSp-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_Signaling_Connection_Control_SccpSp-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_SccpSp' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfLUDTRec' => 4294967295,
	     'pmNoOfLUDTSSent' => 4294967295,
	     'pmNoOfConInUseExceedHighWaterMark' => 4294967295,
	     'pmNoOfConInUseReceededLowWaterMark' => 4294967295,
	     'pmNoOfCREFRecFromNL' => 4294967295,
	     'pmNoOfCREFSentToNL' => 4294967295,
	     'pmNoOfCRRec' => 4294967295,
	     'pmNoOfCRSent' => 4294967295,
	     'pmNoOfDT1Rec' => 4294967295,
	     'pmNoOfDT1Sent' => 4294967295,
	     'pmNoOfERRRec' => 4294967295,
	     'pmNoOfERRSent' => 4294967295,
	     'pmNoOfRLSDRecFromNL' => 4294967295,
	     'pmNoOfRLSDSentToNL' => 4294967295,
	     'pmNoOfSubsysAllowedSent' => 4294967295,
	     'pmNoOfUDTRec' => 4294967295,
	     'pmNoOfUDTSent' => 4294967295,
	     'pmNoOfUDTSRec' => 4294967295,
	     'pmNoOfUDTSSent' => 4294967295,
	     'pmNoOfXUDTRec' => 4294967295,
	     'pmNoOfXUDTSent' => 4294967295,
	     'pmNoOfXUDTSRec' => 4294967295,
	     'pmNoOfXUDTSSent' => 4294967295,
        },
},
# Remove initial PIF after unpegger for RNC_Signaling_Connection_Control_SccpSp
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial RNC_Signaling_Connection_Control_SccpSp PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Signaling_Connection_Control_SccpSp-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : RNC_Signaling_Connection_Control_SccpSp

# START : SCTP
# Unpegger for SCTP NODEB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg SCTP NODEB Counters',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_SCTP-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^NODEB_SCTP-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Sctp' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 'True',
	#OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmSctpAborted' => 4294967295,
	     'pmSctpActiveEstab' => 4294967295,
	     'pmSctpCurrEstab' => 4294967295,
	     'pmSctpPassiveEstab' => 4294967295,
	     'pmSctpShutdowns' => 4294967295,
	     'pmSctpStatAssocOutOfBlue' => 4294967295,
	     'pmSctpStatChecksumErrorCounter' => 4294967295,
	     'pmSctpStatCommResume' => 4294967295,
	     'pmSctpStatCommStop' => 4294967295,
	     'pmSctpStatFragmentedUserMsg' => 4294967295,
	     'pmSctpStatOutOfOrderRecChunks' => 4294967295,
	     'pmSctpStatOutOfOrderSendChunks' => 4294967295,
	     'pmSctpStatReassembledUserMsg' => 4294967295,
	     'pmSctpStatRecChunks' => 4294967295,
	     'pmSctpStatRecChunksDropped' => 4294967295,
	     'pmSctpStatReceivedControlChunks' => 4294967295,
	     'pmSctpStatReceivedPackages' => 4294967295,
	     'pmSctpStatRetransChunks' => 4294967295,
	     'pmSctpStatSentChunks' => 4294967295,
	     'pmSctpStatSentChunksDropped' => 4294967295,
	     'pmSctpStatSentControlChunks' => 4294967295,
	     'pmSctpStatSentPackages' => 4294967295,
        },
},
# Remove initial PIF after unpegger for SCTP NODEB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial SCTP NODEB PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_SCTP-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for SCTP RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg SCTP RNC Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_SCTP-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_SCTP-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Sctp' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmSctpAborted' => 4294967295,
	     'pmSctpActiveEstab' => 4294967295,
	     'pmSctpCurrEstab' => 4294967295,
	     'pmSctpPassiveEstab' => 4294967295,
	     'pmSctpShutdowns' => 4294967295,
	     'pmSctpStatAssocOutOfBlue' => 4294967295,
	     'pmSctpStatChecksumErrorCounter' => 4294967295,
	     'pmSctpStatCommResume' => 4294967295,
	     'pmSctpStatCommStop' => 4294967295,
	     'pmSctpStatFragmentedUserMsg' => 4294967295,
	     'pmSctpStatOutOfOrderRecChunks' => 4294967295,
	     'pmSctpStatOutOfOrderSendChunks' => 4294967295,
	     'pmSctpStatReassembledUserMsg' => 4294967295,
	     'pmSctpStatRecChunks' => 4294967295,
	     'pmSctpStatRecChunksDropped' => 4294967295,
	     'pmSctpStatReceivedControlChunks' => 4294967295,
	     'pmSctpStatReceivedPackages' => 4294967295,
	     'pmSctpStatRetransChunks' => 4294967295,
	     'pmSctpStatSentChunks' => 4294967295,
	     'pmSctpStatSentChunksDropped' => 4294967295,
	     'pmSctpStatSentControlChunks' => 4294967295,
	     'pmSctpStatSentPackages' => 4294967295,
        },
},
# Remove initial PIF after unpegger for SCTP RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial SCTP RNC PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_SCTP-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : SCTP

# START : ME_TN_Mtp3bSpItu_M3uAssociation
# Unpegger for ME_TN_Mtp3bSpItu_M3uAssociation
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg ME_TN_Mtp3bSpItu_M3uAssociation Counters',
	INPUT_FILE_DESCRIPTION	   => '^(ME_TN_Mtp3bSpItu_M3uAssociation-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^ME_TN_Mtp3bSpItu_M3uAssociation-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Mtp3bSpItu', 'moid_M3uAssociation' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfAspacAckReceived' => 4294967295,
	     'pmNoOfAspacAckSent' => 4294967295,
	     'pmNoOfAspacReceived' => 4294967295,
	     'pmNoOfAspacSent' => 4294967295,
	     'pmNoOfAspdnAckReceived' => 4294967295,
	     'pmNoOfAspdnAckSent' => 4294967295,
	     'pmNoOfAspdnReceived' => 4294967295,
	     'pmNoOfAspdnSent' => 4294967295,
	     'pmNoOfAspiaAckReceived' => 4294967295,
	     'pmNoOfAspiaAckSent' => 4294967295,
	     'pmNoOfAspiaReceived' => 4294967295,
	     'pmNoOfAspiaSent' => 4294967295,
	     'pmNoOfAspupAckReceived' => 4294967295,
	     'pmNoOfAspupAckSent' => 4294967295,
	     'pmNoOfAspupReceived' => 4294967295,
	     'pmNoOfAspupSent' => 4294967295,
	     'pmNoOfCommunicationLost' => 4294967295,
	     'pmNoOfCongestions' => 4294967295,
	     'pmNoOfDataMsgRec' => 4294967295,
	     'pmNoOfDataMsgSent' => 4294967295,
	     'pmNoOfDaudMsgRec' => 4294967295,
	     'pmNoOfDaudMsgSent' => 4294967295,
	     'pmNoOfDavaRec' => 4294967295,
	     'pmNoOfDavaSent' => 4294967295,
	     'pmNoOfDunaRec' => 4294967295,
	     'pmNoOfDunaSent' => 4294967295,
	     'pmNoOfDupuRec' => 4294967295,
	     'pmNoOfDupuSent' => 4294967295,
	     'pmNoOfErrorMsgRec' => 4294967295,
	     'pmNoOfErrorMsgSent' => 4294967295,
	     'pmNoOfM3uaDataMsgDiscarded' => 4294967295,
	     'pmNoOfNotifyMsgRec' => 4294967295,
	     'pmNoOfSconRec' => 4294967295,
        },
},
# Remove initial PIF after unpegger for ME_TN_Mtp3bSpItu_M3uAssociation
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ME_TN_Mtp3bSpItu_M3uAssociation PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(ME_TN_Mtp3bSpItu_M3uAssociation-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : ME_TN_Mtp3bSpItu_M3uAssociation

# START : RNC_Signaling_Connection_Ctrl_Acc_Criteria
# Unpegger for RNC_Signaling_Connection_Ctrl_Acc_Criteria
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg RNC_Signaling_Connection_Ctrl_Acc_Criteria Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Signaling_Connection_Ctrl_Acc_Criteria-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_Signaling_Connection_Ctrl_Acc_Criteria-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_SccpSp', 'moid_SccpScrc','SccpAccountingCriteria' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfMsg' => 4294967295,
	     'pmNoOfOctets' => 4294967295,
        },
},
# Remove initial PIF after unpegger for RNC_Signaling_Connection_Ctrl_Acc_Criteria
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial RNC_Signaling_Connection_Ctrl_Acc_Criteria PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Signaling_Connection_Ctrl_Acc_Criteria-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : RNC_Signaling_Connection_Ctrl_Acc_Criteria

# START : RNC_Signaling_Connection_Control_Policing
# Unpegger for RNC_Signaling_Connection_Control_Policing
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg RNC_Signaling_Connection_Control_Policing Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Signaling_Connection_Control_Policing-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_Signaling_Connection_Control_Policing-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_SccpSp', 'moid_SccpScrc','SccpPolicing' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfRejectMsg' => 4294967295,
        },
},
# Remove initial PIF after unpegger for RNC_Signaling_Connection_Control_Policing
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial RNC_Signaling_Connection_Control_Policing PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Signaling_Connection_Control_Policing-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : RNC_Signaling_Connection_Control_Policing

# START : ME_RNC_Eqpt_FastEthernet
# Unpegger for ME_RNC_Eqpt_FastEthernet
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg ME_RNC_Eqpt_FastEthernet Counters',
	INPUT_FILE_DESCRIPTION	   => '^(ME_RNC_Eqpt_FastEthernet-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^ME_RNC_Eqpt_FastEthernet-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_Equipment','moid_ManagedElement','moid_Subrack', 'moid_Slot','moid_PlugInUnit','moid_GeneralProcessingUnit','moid_FastEthernet' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmIfInBroadcastPkts' => 4294967295,
	     'pmIfInDiscards' => 4294967295,
	     'pmIfInErrors' => 4294967295,
	     'pmIfInMulticastPkts' => 4294967295,
	     'pmIfInOctetsHi' => 4294967295,
	     'pmIfInOctetsLo' => 4294967295,
	     'pmIfInUcastPkts' => 4294967295,
	     'pmIfInUnknownProtos' => 4294967295,
	     'pmIfOutBroadcastPkts' => 4294967295,
	     'pmIfOutDiscards' => 4294967295,
	     'pmIfOutErrors' => 4294967295,
	     'pmIfOutMulticastPkts' => 4294967295,
	     'pmIfOutOctetsHi' => 4294967295,
	     'pmIfOutOctetsLo' => 4294967295,
	     'pmIfOutUcastPkts' => 4294967295,
        },
},
# Remove initial PIF after unpegger for ME_RNC_Eqpt_FastEthernet
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ME_RNC_Eqpt_FastEthernet PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(ME_RNC_Eqpt_FastEthernet-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : ME_RNC_Eqpt_FastEthernet

# START : ME_RNC_Eqpt_GigaBitEthernet
# Unpegger for ME_RNC_Eqpt_GigaBitEthernet
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg ME_RNC_Eqpt_GigaBitEthernet Counters',
	INPUT_FILE_DESCRIPTION	   => '^(ME_RNC_Eqpt_GigaBitEthernet-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^ME_RNC_Eqpt_GigaBitEthernet-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_Equipment','moid_ManagedElement','moid_Subrack', 'moid_Slot','moid_PlugInUnit','moid_EtMfg','moid_GigaBitEthernet' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmDot1qTpVlanPortInDiscardsLink1' => 4294967295,
	     'pmDot1qTpVlanPortInDiscardsLink2' => 4294967295,
	     'pmIfInBroadcastPktsLink1' => 4294967295,
	     'pmIfInBroadcastPktsLink2' => 4294967295,
	     'pmIfInDiscardsLink1' => 4294967295,
	     'pmIfInDiscardsLink2' => 4294967295,
	     'pmIfInErrorsLink1' => 4294967295,
	     'pmIfInErrorsLink2' => 4294967295,
	     'pmIfInMulticastPktsLink1' => 4294967295,
	     'pmIfInMulticastPktsLink2' => 4294967295,
	     'pmIfInOctetsLink1Hi' => 4294967295,
	     'pmIfInOctetsLink1Lo' => 4294967295,
	     'pmIfInOctetsLink2Hi' => 4294967295,
	     'pmIfInOctetsLink2Lo' => 4294967295,
	     'pmIfInUcastPktsLink1' => 4294967295,
	     'pmIfInUcastPktsLink2' => 4294967295,
	     'pmIfInUnknownProtosLink1' => 4294967295,
	     'pmIfInUnknownProtosLink2' => 4294967295,
	     'pmIfOutBroadcastPktsLink1' => 4294967295,
	     'pmIfOutBroadcastPktsLink2' => 4294967295,
	     'pmIfOutDiscardsLink1' => 4294967295,
	     'pmIfOutDiscardsLink2' => 4294967295,
	     'pmIfOutErrorsLink1' => 4294967295,
	     'pmIfOutErrorsLink2' => 4294967295,
	     'pmIfOutMulticastPktsLink1' => 4294967295,
	     'pmIfOutMulticastPktsLink2' => 4294967295,
	     'pmIfOutOctetsLink1Hi' => 4294967295,
	     'pmIfOutOctetsLink1Lo' => 4294967295,
	     'pmIfOutOctetsLink2Hi' => 4294967295,
	     'pmIfOutOctetsLink2Lo' => 4294967295,
	     'pmIfOutUcastPktsLink1' => 4294967295,
	     'pmIfOutUcastPktsLink2' => 4294967295,
        },
},
# Remove initial PIF after unpegger for ME_RNC_Eqpt_GigaBitEthernet
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ME_RNC_Eqpt_GigaBitEthernet PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(ME_RNC_Eqpt_GigaBitEthernet-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : ME_RNC_Eqpt_GigaBitEthernet

# START : RNC_IP_Access_Spb
# Unpegger for RNC_IP_Access_Spb
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg RNC_IP_Access_Spb Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_IP_Access_Spb-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_IP_Access_Spb-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_IpAccessHostSpb' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmIcmpInDestUnreachs' => 4294967295,
	     'pmIcmpInEchoReps' => 4294967295,
	     'pmIcmpInEchos' => 4294967295,
	     'pmIcmpInErrors' => 4294967295,
	     'pmIcmpInMsgs' => 4294967295,
	     'pmIcmpInParamProbs' => 4294967295,
	     'pmIcmpInRedirects' => 4294967295,
	     'pmIcmpInSrcQuenchs' => 4294967295,
	     'pmIcmpInTimeExcds' => 4294967295,
	     'pmIcmpOutDestUnreachs' => 4294967295,
	     'pmIcmpOutEchoReps' => 4294967295,
	     'pmIcmpOutEchos' => 4294967295,
	     'pmIcmpOutErrors' => 4294967295,
	     'pmIcmpOutMsgs' => 4294967295,
	     'pmIcmpOutParmProbs' => 4294967295,
	     'pmIpFragCreates' => 4294967295,
	     'pmIpFragFails' => 4294967295,
	     'pmIpFragOKs' => 4294967295,
	     'pmIpInAddrErrors' => 4294967295,
	     'pmIpInDelivers' => 4294967295,
	     'pmIpInDiscards' => 4294967295,
	     'pmIpInHdrErrors' => 4294967295,
	     'pmIpInReceives' => 4294967295,
	     'pmIpInUnknownProtos' => 4294967295,
	     'pmIpOutDiscards' => 4294967295,
	     'pmIpOutRequests' => 4294967295,
	     'pmIpReasmFails' => 4294967295,
	     'pmIpReasmOKs' => 4294967295,
	     'pmIpReasmReqds' => 4294967295,
	     'pmUdpInDatagrams' => 4294967295,
	     'pmUdpInErrors' => 4294967295,
	     'pmUdpNoPorts' => 4294967295,
	     'pmUdpOutDatagrams' => 4294967295,
        },
},
# Remove initial PIF after unpegger for ME_RNC_Eqpt_GigaBitEthernet
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial RNC_IP_Access_Spb PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_IP_Access_Spb-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : RNC_IP_Access_Spb

# START : PlugInUnit_EtMfg_GigaBitEther_IpIntf
# Unpegger for PlugInUnit_EtMfg_GigaBitEther_IpIntf
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg PlugInUnit_EtMfg_GigaBitEther_IpIntf Counters',
	INPUT_FILE_DESCRIPTION	   => '^(PlugInUnit_EtMfg_GigaBitEther_IpIntf-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^PlugInUnit_EtMfg_GigaBitEther_IpIntf-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_Equipment','moid_ManagedElement','moid_Subrack','moid_Slot','moid_PlugInUnit','moid_EtMfg','moid_GigaBitEthernet','moid_IpInterface' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmDot1qTpVlanPortInFrames' => 4294967295,
	     'pmDot1qTpVlanPortOutFrames' => 4294967295,
	     'pmIfStatsIpAddrErrors' => 4294967295,
	     'pmIfStatsIpInDiscards' => 4294967295,
	     'pmIfStatsIpInHdrErrors' => 4294967295,
	     'pmIfStatsIpInReceives' => 4294967295,
	     'pmIfStatsIpOutDiscards' => 4294967295,
	     'pmIfStatsIpOutRequests' => 4294967295,
	     'pmIfStatsIpUnknownProtos' => 4294967295,
        },
},
# Remove initial PIF after unpegger for PlugInUnit_EtMfg_GigaBitEther_IpIntf
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial PlugInUnit_EtMfg_GigaBitEther_IpIntf PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(PlugInUnit_EtMfg_GigaBitEther_IpIntf-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : PlugInUnit_EtMfg_GigaBitEther_IpIntf

# START : IP_Link
# Unpegger for IP_Link NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IP_Link NodeB Counters',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_IP_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^NODEB_IP_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_Ip' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 'True',
	#OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfHdrErrors' => 4294967295,
	     'pmNoOfIpAddrErrors' => 4294967295,
	     'pmNoOfIpInDiscards' => 4294967295,
	     'pmNoOfIpInReceives' => 4294967295,
	     'pmNoOfIpOutDiscards' => 4294967295,
	     'pmNoOfIpReasmOKs' => 4294967295,
	     'pmNoOfIpReasmReqds' => 4294967295,
	     'pmNoOfIpForwDatagrams' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IP_Link NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IP_Link NodeB PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_IP_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for IP_Link RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IP_Link RNC Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_IP_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_IP_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_Ip' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfHdrErrors' => 4294967295,
	     'pmNoOfIpAddrErrors' => 4294967295,
	     'pmNoOfIpInDiscards' => 4294967295,
	     'pmNoOfIpInReceives' => 4294967295,
	     'pmNoOfIpOutDiscards' => 4294967295,
	     'pmNoOfIpReasmOKs' => 4294967295,
	     'pmNoOfIpReasmReqds' => 4294967295,
	     'pmNoOfIpForwDatagrams' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IP_Link RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IP_Link RNC PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_IP_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for IP_Link RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IP_Link RXI Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_IP_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RXI_IP_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_Ip' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfHdrErrors' => 4294967295,
	     'pmNoOfIpAddrErrors' => 4294967295,
	     'pmNoOfIpInDiscards' => 4294967295,
	     'pmNoOfIpInReceives' => 4294967295,
	     'pmNoOfIpOutDiscards' => 4294967295,
	     'pmNoOfIpReasmOKs' => 4294967295,
	     'pmNoOfIpReasmReqds' => 4294967295,
	     'pmNoOfIpForwDatagrams' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IP_Link RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IMA_GROUP RXI PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_IP_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : IP_Link

# START : Ospf
# Unpegger for Ospf NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Ospf NodeB Counters',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_Ospf-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^NODEB_Ospf-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_Ospf' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 'True',
	#OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfOspfOriginateNewLsas' => 4294967295,
	     'pmNoOfOspfRxNewLsas' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Ospf NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Ospf NodeB PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_Ospf-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for IP_Link RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Ospf RNC Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Ospf-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_Ospf-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_Ospf' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfOspfOriginateNewLsas' => 4294967295,
	     'pmNoOfOspfRxNewLsas' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Ospf RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IP_Link RNC PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Ospf-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for Ospf RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Ospf RXI Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_Ospf-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RXI_Ospf-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_Ospf' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfOspfOriginateNewLsas' => 4294967295,
	     'pmNoOfOspfRxNewLsas' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Ospf RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Ospf RXI PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_Ospf-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : Ospf

# START : OspfArea
# Unpegger for OspfArea NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg OspfArea NodeB Counters',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_OspfArea-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^NODEB_OspfArea-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_OspfArea' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 'True',
	#OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfOspfSpfRuns' => 4294967295,
        },
},
# Remove initial PIF after unpegger for OspfArea NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial OspfArea NodeB PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_OspfArea-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for IP_Link RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg OspfArea RNC Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_OspfArea-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_OspfArea-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_OspfArea' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfOspfSpfRuns' => 4294967295,
        },
},
# Remove initial PIF after unpegger for OspfArea RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial OspfArea RNC PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_OspfArea-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for OspfArea RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg OspfArea RXI Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_OspfArea-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RXI_OspfArea-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_OspfArea' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfOspfSpfRuns' => 4294967295,
        },
},
# Remove initial PIF after unpegger for OspfArea RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial OspfArea RXI PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_OspfArea-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : OspfArea

# START : OspfInterface
# Unpegger for OspfInterface NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg OspfInterface NodeB Counters',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_OspfInterface-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^NODEB_OspfInterface-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_OspfInterface' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 'true',
	#OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfOspfIfEvents' => 4294967295,
        },
},
# Remove initial PIF after unpegger for OspfInterface NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial OspfInterface NodeB PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_OspfInterface-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for OspfInterface RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg OspfInterface RNC Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_OspfInterface-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_OspfInterface-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_OspfInterface' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfOspfIfEvents' => 4294967295,
        },
},
# Remove initial PIF after unpegger for OspfInterface RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial OspfInterface RNC PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_OspfArea-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for OspfInterface RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg OspfInterface RXI Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_OspfInterface-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RXI_OspfInterface-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_OspfInterface' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfOspfIfEvents' => 4294967295,
        },
},
# Remove initial PIF after unpegger for OspfInterface RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial OspfInterface RXI PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_OspfInterface-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : OspfInterface

# START : IpSystem_IpAccessHostGpb
# Unpegger for IpSystem_IpAccessHostGpb NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IpSystem_IpAccessHostGpb NodeB Counters',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_IpSystem_IpAccessHostGpb-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^NODEB_IpSystem_IpAccessHostGpb-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_IpAccessHostGpb' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 'True',
	#OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmIcmpInDestUnreachs' => 4294967295,
	     'pmIcmpInEchoReps' => 4294967295,
	     'pmIcmpInEchos' => 4294967295,
	     'pmIcmpInErrors' => 4294967295,
	     'pmIcmpInMsgs' => 4294967295,
	     'pmIcmpInParamProbs' => 4294967295,
	     'pmIcmpInRedirects' => 4294967295,
	     'pmIcmpInSrcQuenchs' => 4294967295,
	     'pmIcmpInTimeExcds' => 4294967295,
	     'pmIcmpOutDestUnreachs' => 4294967295,
	     'pmIcmpOutEchoReps' => 4294967295,
	     'pmIcmpOutEchos' => 4294967295,
	     'pmIcmpOutErrors' => 4294967295,
	     'pmIcmpOutMsgs' => 4294967295,
	     'pmIcmpOutParmProbs' => 4294967295,
	     'pmIpFragCreates' => 4294967295,
	     'pmIpFragFails' => 4294967295,
	     'pmIpFragOKs' => 4294967295,
	     'pmIpInAddrErrors' => 4294967295,
	     'pmIpInDelivers' => 4294967295,
	     'pmIpInDiscards' => 4294967295,
	     'pmIpInHdrErrors' => 4294967295,
	     'pmIpInReceives' => 4294967295,
	     'pmIpInUnknownProtos' => 4294967295,
	     'pmIpOutDiscards' => 4294967295,
	     'pmIpOutRequests' => 4294967295,
	     'pmIpReasmFails' => 4294967295,
	     'pmIpReasmOKs' => 4294967295,
	     'pmIpReasmReqds' => 4294967295,
	     'pmUdpInDatagrams' => 4294967295,
	     'pmUdpInErrors' => 4294967295,
	     'pmUdpNoPorts' => 4294967295,
	     'pmUdpOutDatagrams' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IpSystem_IpAccessHostGpb NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IpSystem_IpAccessHostGpb NodeB PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_IpSystem_IpAccessHostGpb-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for IpSystem_IpAccessHostGpb RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IpSystem_IpAccessHostGpb RNC Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_IpSystem_IpAccessHostGpb-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_IpSystem_IpAccessHostGpb-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_IpAccessHostGpb' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmIcmpInDestUnreachs' => 4294967295,
	     'pmIcmpInEchoReps' => 4294967295,
	     'pmIcmpInEchos' => 4294967295,
	     'pmIcmpInErrors' => 4294967295,
	     'pmIcmpInMsgs' => 4294967295,
	     'pmIcmpInParamProbs' => 4294967295,
	     'pmIcmpInRedirects' => 4294967295,
	     'pmIcmpInSrcQuenchs' => 4294967295,
	     'pmIcmpInTimeExcds' => 4294967295,
	     'pmIcmpOutDestUnreachs' => 4294967295,
	     'pmIcmpOutEchoReps' => 4294967295,
	     'pmIcmpOutEchos' => 4294967295,
	     'pmIcmpOutErrors' => 4294967295,
	     'pmIcmpOutMsgs' => 4294967295,
	     'pmIcmpOutParmProbs' => 4294967295,
	     'pmIpFragCreates' => 4294967295,
	     'pmIpFragFails' => 4294967295,
	     'pmIpFragOKs' => 4294967295,
	     'pmIpInAddrErrors' => 4294967295,
	     'pmIpInDelivers' => 4294967295,
	     'pmIpInDiscards' => 4294967295,
	     'pmIpInHdrErrors' => 4294967295,
	     'pmIpInReceives' => 4294967295,
	     'pmIpInUnknownProtos' => 4294967295,
	     'pmIpOutDiscards' => 4294967295,
	     'pmIpOutRequests' => 4294967295,
	     'pmIpReasmFails' => 4294967295,
	     'pmIpReasmOKs' => 4294967295,
	     'pmIpReasmReqds' => 4294967295,
	     'pmUdpInDatagrams' => 4294967295,
	     'pmUdpInErrors' => 4294967295,
	     'pmUdpNoPorts' => 4294967295,
	     'pmUdpOutDatagrams' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IpSystem_IpAccessHostGpb RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IpSystem_IpAccessHostGpb RNC PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_IpSystem_IpAccessHostGpb-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : IpSystem_IpAccessHostGpb

# START : IpSystem_IpAccessUdpHostMsb
# Unpegger for IpSystem_IpAccessUdpHostMsb NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IpSystem_IpAccessUdpHostMsb NodeB Counters',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_IpSystem_IpAccessUdpHostMsb-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^NODEB_IpSystem_IpAccessUdpHostMsb-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_UdpHostMainMsb', 'moid_IpAccessUdpHostMsb' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 'True',
	#OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmIcmpInDestUnreachs' => 4294967295,
	     'pmIcmpInErrors' => 4294967295,
	     'pmIcmpInMsgs' => 4294967295,
	     'pmIcmpOutDestUnreachs' => 4294967295,
	     'pmIcmpOutMsgs' => 4294967295,
	     'pmIpInAddrErrors' => 4294967295,
	     'pmIpInDelivers' => 4294967295,
	     'pmIpInDiscards' => 4294967295,
	     'pmIpInHdrErrors' => 4294967295,
	     'pmIpInReceives' => 4294967295,
	     'pmIpInUnknownProtos' => 4294967295,
	     'pmIpOutDiscards' => 4294967295,
	     'pmIpOutRequests' => 4294967295,
	     'pmUdpInDatagrams' => 4294967295,
	     'pmUdpInErrors' => 4294967295,
	     'pmUdpNoPorts' => 4294967295,
	     'pmUdpOutDatagrams' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IpSystem_IpAccessUdpHostMsb NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IpSystem_IpAccessUdpHostMsb NodeB PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_IpSystem_IpAccessUdpHostMsb-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for IpSystem_IpAccessUdpHostMsb RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IpSystem_IpAccessUdpHostMsb RNC Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_IpSystem_IpAccessUdpHostMsb-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_IpSystem_IpAccessUdpHostMsb-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_UdpHostMainMsb', 'moid_IpAccessUdpHostMsb' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmIcmpInDestUnreachs' => 4294967295,
	     'pmIcmpInErrors' => 4294967295,
	     'pmIcmpInMsgs' => 4294967295,
	     'pmIcmpOutDestUnreachs' => 4294967295,
	     'pmIcmpOutMsgs' => 4294967295,
	     'pmIpInAddrErrors' => 4294967295,
	     'pmIpInDelivers' => 4294967295,
	     'pmIpInDiscards' => 4294967295,
	     'pmIpInHdrErrors' => 4294967295,
	     'pmIpInReceives' => 4294967295,
	     'pmIpInUnknownProtos' => 4294967295,
	     'pmIpOutDiscards' => 4294967295,
	     'pmIpOutRequests' => 4294967295,
	     'pmUdpInDatagrams' => 4294967295,
	     'pmUdpInErrors' => 4294967295,
	     'pmUdpNoPorts' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IpSystem_IpAccessUdpHostMsb RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IpSystem_IpAccessUdpHostMsb RNC PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_IpSystem_IpAccessUdpHostMsb-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : IpSystem_IpAccessUdpHostMsb

# START : Mtp2tpItu
# Unpegger for Mtp2tpItu NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Mtp2tpItu NodeB Counters',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_Mtp2tpItu-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^NODEB_Mtp2tpItu-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Mtp2tpItu' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 'True',
	#OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfMSUReceived' => 4294967295,
	     'pmNoOfMSUTransmitted' => 4294967295,
	     'pmNoOfNacks' => 4294967295,
	     'pmNoOfReTransmittedOctets' => 4294967295,
	     'pmNoOfSIOSIFReceived' => 4294967295,
	     'pmNoOfSIOSIFTransmitted' => 4294967295,
	     'pmNoOfSendBufferOctets' => 4294967295,
	     'pmNoOfStartedRBCongestion' => 4294967295,
	     'pmNoOfSuReceivedInError' => 4294967295,
	     'pmRemoteSIBTime' => 4294967295,
	     'pmLocalSIBTime' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Mtp2tpItu NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Mtp2tpItu NodeB PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_Mtp2tpItu-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for Mtp2tpItu RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Mtp2tpItu RNC Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Mtp2tpItu-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_Mtp2tpItu-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Mtp2tpItu' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfMSUReceived' => 4294967295,
	     'pmNoOfMSUTransmitted' => 4294967295,
	     'pmNoOfNacks' => 4294967295,
	     'pmNoOfReTransmittedOctets' => 4294967295,
	     'pmNoOfSIOSIFReceived' => 4294967295,
	     'pmNoOfSIOSIFTransmitted' => 4294967295,
	     'pmNoOfSendBufferOctets' => 4294967295,
	     'pmNoOfStartedRBCongestion' => 4294967295,
	     'pmNoOfSuReceivedInError' => 4294967295,
	     'pmRemoteSIBTime' => 4294967295,
	     'pmLocalSIBTime' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Mtp2tpItu RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Mtp2tpItu RNC PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Mtp2tpItu-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : Mtp2tpItu

# START : Processor_Load
# Unpegger for Processor_Load RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Processor_Load RXI Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_Processor_Load-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RXI_Processor_Load-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_Equipment','moid_ManagedElement','moid_Subrack','moid_Slot','moid_PlugInUnit','moid_GeneralProcessorUnit','moid_MediumAccessUnit' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfDot3StatsFCSErrors' => 4294967295,
	     'pmNoOfDot3StatsLateCollisions' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Processor_Load RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Processor_Load NodeB PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_Processor_Load-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for Processor_Load RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Processor_Load RNC Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Processor_Load-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_Processor_Load-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_Equipment','moid_ManagedElement','moid_Subrack','moid_Slot','moid_PlugInUnit','moid_GeneralProcessorUnit','moid_MediumAccessUnit' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfDot3StatsFCSErrors' => 4294967295,
	     'pmNoOfDot3StatsLateCollisions' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Processor_Load RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Processor_Load RNC PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Processor_Load-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : Processor_Load

# START : ATM_Port
# Unpegger for ATM_Port NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg ATM_Port NodeB Counters',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_ATM_Physical_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^NODEB_ATM_Physical_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_AtmPort' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 'True',
	#OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmTransmittedAtmCells' => 4294967295,
	     'pmReceivedAtmCells' => 4294967295,
	     'pmSecondsWithUnexp' => 4294967295,
        },
},
# Remove initial PIF after unpegger for ATM_Port NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ATM_Port NodeB PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_ATM_Physical_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for ATM_Port RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg ATM_Port RNC Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_ATM_Physical_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_ATM_Physical_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_AtmPort' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmTransmittedAtmCells' => 4294967295,
	     'pmReceivedAtmCells' => 4294967295,
	     'pmSecondsWithUnexp' => 4294967295,
        },
},
# Remove initial PIF after unpegger for ATM_Port RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ATM_Port RNC PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_ATM_Physical_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for ATM_Port RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg ATM_Port RXI Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_ATM_Physical_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RXI_ATM_Physical_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_AtmPort' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 'True',
        #OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmTransmittedAtmCells' => 4294967295,
	     'pmReceivedAtmCells' => 4294967295,
	     'pmSecondsWithUnexp' => 4294967295,
        },
},
# Remove initial PIF after unpegger for ATM_Port RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ATM_Port RXI PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_ATM_Physical_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : ATM_Port

# START : Ethernet_Link
# Unpegger for Ethernet_Link NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Ethernet_Link NodeB Counters',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_Ethernet_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^NODEB_Ethernet_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement','moid_EthernetLink','moid_IpSystem','moid_Ip' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 'True',
	#OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfIfOutDiscards'  => 4294967295,
	     'pmNoOfIfInDiscards'  => 4294967295,
	     'pmNoOfIfInErrors'  => 4294967295,
	     'pmNoOfIfInNUcastPkts'  => 4294967295,
	     'pmNoOfIfInUcastPkts'  => 4294967295,
	     'pmNoOfIfOutNUcastPkts'  => 4294967295,
	     'pmNoOfIfOutUcastPkts'  => 4294967295,
        },
},
# Remove initial PIF after unpegger for Ethernet_Link NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Ethernet_Link NodeB PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_Ethernet_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for Ethernet_Link RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Ethernet_Link RNC Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Ethernet_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_Ethernet_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement','moid_EthernetLink','moid_IpSystem','moid_Ip' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfIfOutDiscards'  => 4294967295,
	     'pmNoOfIfInDiscards'  => 4294967295,
	     'pmNoOfIfInErrors'  => 4294967295,
	     'pmNoOfIfInNUcastPkts'  => 4294967295,
	     'pmNoOfIfInUcastPkts'  => 4294967295,
	     'pmNoOfIfOutNUcastPkts'  => 4294967295,
	     'pmNoOfIfOutUcastPkts'  => 4294967295,
        },
},
# Remove initial PIF after unpegger for Ethernet_Link RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Ethernet_Link RNC PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Ethernet_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for Ethernet_Link RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Ethernet_Link RXI Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_Ethernet_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RXI_Ethernet_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement','moid_EthernetLink','moid_IpSystem','moid_Ip' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfIfOutDiscards'  => 4294967295,
	     'pmNoOfIfInDiscards'  => 4294967295,
	     'pmNoOfIfInErrors'  => 4294967295,
	     'pmNoOfIfInNUcastPkts'  => 4294967295,
	     'pmNoOfIfInUcastPkts'  => 4294967295,
	     'pmNoOfIfOutNUcastPkts'  => 4294967295,
	     'pmNoOfIfOutUcastPkts'  => 4294967295,
        },
},
# Remove initial PIF after unpegger for Ethernet_Link RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Ethernet_Link RXI PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_Ethernet_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : Ethernet_Link

# START : IP_ATM_Link
# Unpegger for IP_ATM_Link NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IP_ATM_Link NodeB Counters',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_IP_ATM_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^NODEB_IP_ATM_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement','moid_IpAtmLink', 'moid_Ip' ,'moid_IpSystem' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 'True',
	#OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfIfInDiscards' => 4294967295,
	     'pmNoOfIfInErrors' => 4294967295,
	     'pmNoOfIfInNUcastPkts' => 4294967295,
	     'pmNoOfIfInUcastPkts' => 4294967295,
	     'pmNoOfIfOutNUcastPkts' => 4294967295,
	     'pmNoOfIfOutUcastPkts' => 4294967295,
	     'pmNoOfIfOutDiscards' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IP_ATM_Link NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IP_ATM_Link NodeB PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_IP_ATM_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for IP_ATM_Link RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IP_ATM_Link RNC Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_IP_ATM_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_IP_ATM_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement','moid_IpAtmLink', 'moid_Ip' ,'moid_IpSystem' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfIfInDiscards' => 4294967295,
	     'pmNoOfIfInErrors' => 4294967295,
	     'pmNoOfIfInNUcastPkts' => 4294967295,
	     'pmNoOfIfInUcastPkts' => 4294967295,
	     'pmNoOfIfOutNUcastPkts' => 4294967295,
	     'pmNoOfIfOutUcastPkts' => 4294967295,
	     'pmNoOfIfOutDiscards' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IP_ATM_Link RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IP_ATM_Link RNC PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_IP_ATM_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for IP_ATM_Link RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IP_ATM_Link RXI Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_IP_ATM_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RXI_IP_ATM_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement','moid_IpAtmLink', 'moid_Ip' ,'moid_IpSystem' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmNoOfIfInDiscards' => 4294967295,
	     'pmNoOfIfInErrors' => 4294967295,
	     'pmNoOfIfInNUcastPkts' => 4294967295,
	     'pmNoOfIfInUcastPkts' => 4294967295,
	     'pmNoOfIfOutNUcastPkts' => 4294967295,
	     'pmNoOfIfOutUcastPkts' => 4294967295,
	     'pmNoOfIfOutDiscards' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IP_ATM_Link RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IP_ATM_Link RXI PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_IP_ATM_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : IP_ATM_Link

# START : NniSAalTp_Signaling
# Unpegger for NniSAalTp_Signaling NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg NniSAalTp_Signaling NodeB Counters',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_NniSAalTp_Signaling-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^NODEB_NniSAalTp_Signaling-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement', 'moid_TransportNetwork', 'moid_NniSaalTp' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 'True',
	#OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmLinkInServiceTime' => 4294967295,
	     'pmNoOfAlignmentFailures' => 4294967295,
	     'pmNoOfAllSLFailures' => 4294967295,
	     'pmNoOfLocalCongestions' => 4294967295,
	     'pmNoOfNoResponses' => 4294967295,
	     'pmNoOfOtherErrors' => 4294967295,
	     'pmNoOfProtocolErrors' => 4294967295,
	     'pmNoOfReceivedSDUs' => 4294967295,
	     'pmNoOfRemoteCongestions' => 4294967295,
	     'pmNoOfSentSDUs' => 4294967295,
	     'pmNoOfSequenceDataLosses' => 4294967295,
	     'pmNoOfUnsuccReTransmissions' => 4294967295,
        },
},
# Remove initial PIF after unpegger for NniSAalTp_Signaling NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial NniSAalTp_Signaling NodeB PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_NniSAalTp_Signaling-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for NniSAalTp_Signaling RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg NniSAalTp_Signaling RNC Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_NniSAalTp_Signaling-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_NniSAalTp_Signaling-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement', 'moid_TransportNetwork', 'moid_NniSaalTp' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmLinkInServiceTime' => 4294967295,
	     'pmNoOfAlignmentFailures' => 4294967295,
	     'pmNoOfAllSLFailures' => 4294967295,
	     'pmNoOfLocalCongestions' => 4294967295,
	     'pmNoOfNoResponses' => 4294967295,
	     'pmNoOfOtherErrors' => 4294967295,
	     'pmNoOfProtocolErrors' => 4294967295,
	     'pmNoOfReceivedSDUs' => 4294967295,
	     'pmNoOfRemoteCongestions' => 4294967295,
	     'pmNoOfSentSDUs' => 4294967295,
	     'pmNoOfSequenceDataLosses' => 4294967295,
	     'pmNoOfUnsuccReTransmissions' => 4294967295,
        },
},
# Remove initial PIF after unpegger for NniSAalTp_Signaling RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial NniSAalTp_Signaling RNC PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_NniSAalTp_Signaling-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for NniSAalTp_Signaling RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg NniSAalTp_Signaling RXI Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_NniSAalTp_Signaling-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RXI_NniSAalTp_Signaling-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement', 'moid_TransportNetwork', 'moid_NniSaalTp' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmLinkInServiceTime' => 4294967295,
	     'pmNoOfAlignmentFailures' => 4294967295,
	     'pmNoOfAllSLFailures' => 4294967295,
	     'pmNoOfLocalCongestions' => 4294967295,
	     'pmNoOfNoResponses' => 4294967295,
	     'pmNoOfOtherErrors' => 4294967295,
	     'pmNoOfProtocolErrors' => 4294967295,
	     'pmNoOfReceivedSDUs' => 4294967295,
	     'pmNoOfRemoteCongestions' => 4294967295,
	     'pmNoOfSentSDUs' => 4294967295,
	     'pmNoOfSequenceDataLosses' => 4294967295,
	     'pmNoOfUnsuccReTransmissions' => 4294967295,
        },
},
# Remove initial PIF after unpegger for NniSAalTp_Signaling RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial NniSAalTp_Signaling RXI PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_NniSAalTp_Signaling-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : NniSAalTp_Signaling

# START : UniSAalTp_Signaling
# Unpegger for UniSAalTp_Signaling NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg UniSAalTp_Signaling NodeB Counters',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_UniSAalTp_Signaling-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^NODEB_UniSAalTp_Signaling-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement', 'moid_TransportNetwork', 'moid_UniSaalTp' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 'True',
	#OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmLinkInServiceTime' => 4294967295,
	     'pmNoOfAlignmentFailures' => 4294967295,
	     'pmNoOfLocalCongestions' => 4294967295,
	     'pmNoOfNoResponses' => 4294967295,
	     'pmNoOfOtherErrors' => 4294967295,
	     'pmNoOfProtocolErrors' => 4294967295,
	     'pmNoOfReceivedSDUs' => 4294967295,
	     'pmNoOfRemoteCongestions' => 4294967295,
	     'pmNoOfSentSDUs' => 4294967295,
	     'pmNoOfSequenceDataLosses' => 4294967295,
	     'pmNoOfUnsuccReTransmissions' => 4294967295,
	     'FailNoOfSL' => 4294967295,
	     'pmNoOfAllSLFailures' => 4294967295,
        },
},
# Remove initial PIF after unpegger for UniSAalTp_Signaling NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial UniSAalTp_Signaling NodeB PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_UniSAalTp_Signaling-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for UniSAalTp_Signaling RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg UniSAalTp_Signaling RNC Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_UniSAalTp_Signaling-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_UniSAalTp_Signaling-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement', 'moid_TransportNetwork', 'moid_UniSaalTp' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmLinkInServiceTime' => 4294967295,
	     'pmNoOfAlignmentFailures' => 4294967295,
	     'pmNoOfLocalCongestions' => 4294967295,
	     'pmNoOfNoResponses' => 4294967295,
	     'pmNoOfOtherErrors' => 4294967295,
	     'pmNoOfProtocolErrors' => 4294967295,
	     'pmNoOfReceivedSDUs' => 4294967295,
	     'pmNoOfRemoteCongestions' => 4294967295,
	     'pmNoOfSentSDUs' => 4294967295,
	     'pmNoOfSequenceDataLosses' => 4294967295,
	     'pmNoOfUnsuccReTransmissions' => 4294967295,
	     'FailNoOfSL' => 4294967295,
	     'pmNoOfAllSLFailures' => 4294967295,
        },
},
# Remove initial PIF after unpegger for UniSAalTp_Signaling RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial UniSAalTp_Signaling RNC PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_UniSAalTp_Signaling-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for UniSAalTp_Signaling RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg UniSAalTp_Signaling RXI Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_UniSAalTp_Signaling-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RXI_UniSAalTp_Signaling-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement', 'moid_TransportNetwork', 'moid_UniSaalTp' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmLinkInServiceTime' => 4294967295,
	     'pmNoOfAlignmentFailures' => 4294967295,
	     'pmNoOfLocalCongestions' => 4294967295,
	     'pmNoOfNoResponses' => 4294967295,
	     'pmNoOfOtherErrors' => 4294967295,
	     'pmNoOfProtocolErrors' => 4294967295,
	     'pmNoOfReceivedSDUs' => 4294967295,
	     'pmNoOfRemoteCongestions' => 4294967295,
	     'pmNoOfSentSDUs' => 4294967295,
	     'pmNoOfSequenceDataLosses' => 4294967295,
	     'pmNoOfUnsuccReTransmissions' => 4294967295,
	     'FailNoOfSL' => 4294967295,
	     'pmNoOfAllSLFailures' => 4294967295,
        },
},
# Remove initial PIF after unpegger for UniSAalTp_Signaling RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial UniSAalTp_Signaling RXI PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_UniSAalTp_Signaling-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : UniSAalTp_Signaling

# START : Virtual_Channel_Link
# Unpegger for Virtual_Channel_Link NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Virtual_Channel_Link NodeB Counters',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_Virtual_Channel_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^NODEB_Virtual_Channel_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_AtmPort','moid_VclTp','moid_VplTp','moid_VpcTp' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 'True',
	#OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmReceivedAtmCells' => 4294967295,
	     'pmTransmittedAtmCells' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Virtual_Channel_Link NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Virtual_Channel_Link NodeB PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_Virtual_Channel_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for Virtual_Channel_Link RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Virtual_Channel_Link RNC Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Virtual_Channel_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_Virtual_Channel_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_AtmPort','moid_VclTp','moid_VplTp','moid_VpcTp' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmReceivedAtmCells' => 4294967295,
	     'pmTransmittedAtmCells' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Virtual_Channel_Link RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Virtual_Channel_Link RNC PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Virtual_Channel_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for Virtual_Channel_Link RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Virtual_Channel_Link RXI Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_Virtual_Channel_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RXI_Virtual_Channel_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_AtmPort','moid_VclTp','moid_VplTp','moid_VpcTp' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 'True',
	#OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmReceivedAtmCells' => 4294967295,
	     'pmTransmittedAtmCells' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Virtual_Channel_Link RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Virtual_Channel_Link RXI PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_Virtual_Channel_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : Virtual_Channel_Link

# START : Virtual_Path_Connection
# Unpegger for Virtual_Path_Connection NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Virtual_Path_Connection NodeB Counters',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_Virtual_Path_Connection-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^NODEB_Virtual_Path_Connection-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_AtmPort','moid_VplTp','moid_VpcTp' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 'True',
	#OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmBwErrBlocks' => 4294967295,
	     'pmBwLostCells' => 4294967295,
	     'pmBwMissinsCells' => 4294967295,
	     'pmFwErrBlocks' => 4294967295,
	     'pmFwLostCells' => 4294967295,
	     'pmFwMissinsCells' => 4294967295,
	     'pmLostBrCells' => 4294967295,
	     'pmLostFpmCells' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Virtual_Path_Connection NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Virtual_Path_Connection NodeB PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_Virtual_Path_Connection-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for Virtual_Channel_Link RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Virtual_Path_Connection RNC Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Virtual_Path_Connection-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_Virtual_Path_Connection-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_AtmPort','moid_VplTp','moid_VpcTp' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmBwErrBlocks' => 4294967295,
	     'pmBwLostCells' => 4294967295,
	     'pmBwMissinsCells' => 4294967295,
	     'pmFwErrBlocks' => 4294967295,
	     'pmFwLostCells' => 4294967295,
	     'pmFwMissinsCells' => 4294967295,
	     'pmLostBrCells' => 4294967295,
	     'pmLostFpmCells' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Virtual_Path_Connection RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Virtual_Path_Connection RNC PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Virtual_Path_Connection-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for Virtual_Path_Connection RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Virtual_Path_Connection RXI Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_Virtual_Path_Connection-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RXI_Virtual_Path_Connection-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_AtmPort','moid_VplTp','moid_VpcTp' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmBwErrBlocks' => 4294967295,
	     'pmBwLostCells' => 4294967295,
	     'pmBwMissinsCells' => 4294967295,
	     'pmFwErrBlocks' => 4294967295,
	     'pmFwLostCells' => 4294967295,
	     'pmFwMissinsCells' => 4294967295,
	     'pmLostBrCells' => 4294967295,
	     'pmLostFpmCells' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Virtual_Path_Connection RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Virtual_Path_Connection RXI PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_Virtual_Path_Connection-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : Virtual_Channel_Link

# START : Virtual_Path_Link
# Unpegger for Virtual_Path_Link NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Virtual_Path_Link NodeB Counters',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_Virtual_Path_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^NODEB_Virtual_Path_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_AtmPort','moid_VplTp' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 'True',
	#OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmReceivedAtmCells' => 4294967295,
	     'pmTransmittedAtmCells' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Virtual_Path_Link NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Virtual_Path_Link NodeB PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(NODEB_Virtual_Path_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for Virtual_Path_Link RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Virtual_Path_Link RNC Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Virtual_Path_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RNC_Virtual_Path_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_AtmPort','moid_VplTp' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 'True',
	OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmReceivedAtmCells' => 4294967295,
	     'pmTransmittedAtmCells' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Virtual_Path_Link RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Virtual_Path_Link RNC PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RNC_Virtual_Path_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for Virtual_Path_Link RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Virtual_Path_Link RXI Counters',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_Virtual_Path_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
	INPUT_FILE_DATETIME_KEY	   => '^RXI_Virtual_Path_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
	INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_AtmPort','moid_VplTp' ],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 'True',
	#OUTPUT_FORMAT		   => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
	     'pmReceivedAtmCells' => 4294967295,
	     'pmTransmittedAtmCells' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Virtual_Path_Link RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Virtual_Path_Link RXI PIF files',
	INPUT_FILE_DESCRIPTION	   => '^(RXI_Virtual_Path_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : Virtual_Path_Link


# START : UeRc
# Join of UeRc 
{
        RULE_TYPE              => 'JOIN',
        RULE_DESC              => 'Join of RncFunction UeRc files',
        INPUT_FILE_DESCRIPTION 	=> ['^ManagedElement_RncFunction_UeRc-#-(.+)-#-\d+-#-I\.pif$',],
	COUNTERS_TO_JOIN_ON    => ['nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement', 'moid_RncFunction', 'moid_UeRc'],
	HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UeRc',
	OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UeRc',
	HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_SubNetwork', 'nedn_MeContext','mts'],
        PRODUCE_PIF            => 'True',
	OUTPUT_FORMAT	=> 'LIF_Writer',
},
# Aggregation of UeRc 
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate UeRc blocks',
        INPUT_FILE_DESCRIPTION 	=> ['^ManagedElement_RncFunction_UeRc-#-.+-#-J\.pif$',],
        COUNTERS_TO_SORT_ON    => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        NON_ADDITIVE_COUNTERS  => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UeRc_ACCUM',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UeRc_ACCUM',
        PRODUCE_PIF            => 0,
	OUTPUT_FORMAT	=> 'LIF_Writer',
},
# Prepare for CQ aggregation
{
        RULE_TYPE              => 'DATALINE_WHERE',
        RULE_DESC              => 'Dataline to select only UeRc_4/5/6/7/15/16/26/27/28/29/30/31/32/39 for CQ aggregation',
        INPUT_FILE_DESCRIPTION 	=> ['^ManagedElement_RncFunction_UeRc-#-.+-#-J\.pif$',],
        COUNTER_NAMES          => [ 
	{
        	'COUNTER_NAME'   => 'moid_UeRc',
        	'KEEP_WHERE'     => [
			'^4$', '^5$', '^6$', '^7$', '^15$',
			'^16$', '^26$', '^27$', '^28$', '^29$',
			'^30$', '^31$', '^32$', '^39$',
		],
        	'REMOVE_WHERE'   => [],
        }
        ],
	FILENAME_ADDITION	=> 'CQ',
        PRODUCE_PIF 		=> 'True',
	OUTPUT_FORMAT		=> 0,
},
# Actual CQ aggregation
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate UeRc CQ blocks',
        INPUT_FILE_DESCRIPTION 	=> ['^ManagedElement_RncFunction_UeRc-#-.+-#-J-#-CQ-#-DW\.pif$',],
        COUNTERS_TO_SORT_ON    => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        NON_ADDITIVE_COUNTERS  => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UeRc_CQ',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UeRc_CQ',
        PRODUCE_PIF            => 0,
	OUTPUT_FORMAT	=> 'LIF_Writer',
},
# Prepare for TV aggregation
{
        RULE_TYPE              => 'DATALINE_WHERE',
        RULE_DESC              => 'Dataline to select only UeRc_5/6/7/15/16/26/27/28/29/30/31/32/39 for TV aggregation',
        INPUT_FILE_DESCRIPTION 	=> ['^ManagedElement_RncFunction_UeRc-#-.+-#-J\.pif$',],
        COUNTER_NAMES          => [ 
	{
        	'COUNTER_NAME'   => 'moid_UeRc',
        	'KEEP_WHERE'     => [
			'^5$', '^6$', '^7$', '^15$', '^16$',
			'^26$', '^27$', '^28$', '^29$', '^30$',
			'^31$', '^32$', '^39$',
		],
        	'REMOVE_WHERE'   => [],
        }
        ],
	FILENAME_ADDITION	=> 'TV',
        PRODUCE_PIF 		=> 'True',
	OUTPUT_FORMAT		=> 0,
},
# Actual TV aggregation
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate UeRc TV blocks',
        INPUT_FILE_DESCRIPTION 	=> ['^ManagedElement_RncFunction_UeRc-#-.+-#-J-#-TV-#-DW\.pif$',],
        COUNTERS_TO_SORT_ON    => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        NON_ADDITIVE_COUNTERS  => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UeRc_TV',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UeRc_TV',
        PRODUCE_PIF            => 0,
	OUTPUT_FORMAT	=> 'LIF_Writer',
},
# Prepare for UeRc_2 aggregation
{
        RULE_TYPE              => 'DATALINE_WHERE',
        RULE_DESC              => 'Dataline to select only UeRc_2 for aggregation',
        INPUT_FILE_DESCRIPTION 	=> ['^ManagedElement_RncFunction_UeRc-#-.+-#-J\.pif$',],
        COUNTER_NAMES          => [ 
	{
        	'COUNTER_NAME'   => 'moid_UeRc',
        	'KEEP_WHERE'     => [ '^2$', ],
        	'REMOVE_WHERE'   => [],
        }
        ],
	FILENAME_ADDITION	=> 'UeRc_2',
        PRODUCE_PIF 		=> 'True',
	OUTPUT_FORMAT		=> 0,
},
# Actual aggregation of UeRc_2
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate UeRc_2 blocks',
        INPUT_FILE_DESCRIPTION 	=> ['^ManagedElement_RncFunction_UeRc-#-.+-#-J-#-UeRc_2-#-DW\.pif$',],
        COUNTERS_TO_SORT_ON    => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        NON_ADDITIVE_COUNTERS  => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UeRc_2',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UeRc_2',
        PRODUCE_PIF            => 0,
	OUTPUT_FORMAT	=> 'LIF_Writer',
},
# Prepare for UeRc_3 aggregation
{
        RULE_TYPE              => 'DATALINE_WHERE',
        RULE_DESC              => 'Dataline to select only UeRc_3 for aggregation',
        INPUT_FILE_DESCRIPTION 	=> ['^ManagedElement_RncFunction_UeRc-#-.+-#-J\.pif$',],
        COUNTER_NAMES          => [ 
	{
        	'COUNTER_NAME'   => 'moid_UeRc',
        	'KEEP_WHERE'     => [ '^3$', ],
        	'REMOVE_WHERE'   => [],
        }
        ],
	FILENAME_ADDITION	=> 'UeRc_3',
        PRODUCE_PIF 		=> 'True',
	OUTPUT_FORMAT		=> 0,
},
# Actual aggregation of UeRc_3
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate UeRc_3 blocks',
        INPUT_FILE_DESCRIPTION 	=> ['^ManagedElement_RncFunction_UeRc-#-.+-#-J-#-UeRc_3-#-DW\.pif$',],
        COUNTERS_TO_SORT_ON    => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        NON_ADDITIVE_COUNTERS  => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UeRc_3',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UeRc_3',
        PRODUCE_PIF            => 0,
	OUTPUT_FORMAT	=> 'LIF_Writer',
},
# Prepare for UeRc_4 aggregation
{
        RULE_TYPE              => 'DATALINE_WHERE',
        RULE_DESC              => 'Dataline to select only UeRc_4 for aggregation',
        INPUT_FILE_DESCRIPTION 	=> ['^ManagedElement_RncFunction_UeRc-#-.+-#-J\.pif$',],
        COUNTER_NAMES          => [ 
	{
        	'COUNTER_NAME'   => 'moid_UeRc',
        	'KEEP_WHERE'     => [ '^4$', ],
        	'REMOVE_WHERE'   => [],
        }
        ],
	FILENAME_ADDITION	=> 'UeRc_4',
        PRODUCE_PIF 		=> 'True',
	OUTPUT_FORMAT		=> 0,
},
# Actual aggregation of UeRc_4
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate UeRc_4 blocks',
        INPUT_FILE_DESCRIPTION 	=> ['^ManagedElement_RncFunction_UeRc-#-.+-#-J-#-UeRc_4-#-DW\.pif$',],
        COUNTERS_TO_SORT_ON    => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        NON_ADDITIVE_COUNTERS  => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UeRc_4',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UeRc_4',
        PRODUCE_PIF            => 0,
	OUTPUT_FORMAT	=> 'LIF_Writer',
},
# Prepare for UeRc_8 aggregation
{
        RULE_TYPE              => 'DATALINE_WHERE',
        RULE_DESC              => 'Dataline to select only UeRc_8 for aggregation',
        INPUT_FILE_DESCRIPTION 	=> ['^ManagedElement_RncFunction_UeRc-#-.+-#-J\.pif$',],
        COUNTER_NAMES          => [ 
	{
        	'COUNTER_NAME'   => 'moid_UeRc',
        	'KEEP_WHERE'     => [ '^8$', ],
        	'REMOVE_WHERE'   => [],
        }
        ],
	FILENAME_ADDITION	=> 'UeRc_8',
        PRODUCE_PIF 		=> 'True',
	OUTPUT_FORMAT		=> 0,
},
# Actual aggregation of UeRc_8
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate UeRc_8 blocks',
        INPUT_FILE_DESCRIPTION 	=> ['^ManagedElement_RncFunction_UeRc-#-.+-#-J-#-UeRc_8-#-DW\.pif$',],
        COUNTERS_TO_SORT_ON    => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        NON_ADDITIVE_COUNTERS  => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UeRc_8',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UeRc_8',
        PRODUCE_PIF            => 0,
	OUTPUT_FORMAT	=> 'LIF_Writer',
},
# Prepare for UeRc_10 aggregation
{
        RULE_TYPE              => 'DATALINE_WHERE',
        RULE_DESC              => 'Dataline to select only UeRc_10 for aggregation',
        INPUT_FILE_DESCRIPTION 	=> ['^ManagedElement_RncFunction_UeRc-#-.+-#-J\.pif$',],
        COUNTER_NAMES          => [ 
	{
        	'COUNTER_NAME'   => 'moid_UeRc',
        	'KEEP_WHERE'     => [ '^10$', ],
        	'REMOVE_WHERE'   => [],
        }
        ],
	FILENAME_ADDITION	=> 'UeRc_10',
        PRODUCE_PIF 		=> 'True',
	OUTPUT_FORMAT		=> 0,
},
# Actual aggregation of UeRc_10
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate UeRc_10 blocks',
        INPUT_FILE_DESCRIPTION 	=> ['^ManagedElement_RncFunction_UeRc-#-.+-#-J-#-UeRc_10-#-DW\.pif$',],
        COUNTERS_TO_SORT_ON    => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        NON_ADDITIVE_COUNTERS  => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UeRc_10',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UeRc_10',
        PRODUCE_PIF            => 0,
	OUTPUT_FORMAT	=> 'LIF_Writer',
},
# Prepare for UeRc_13 aggregation
{
        RULE_TYPE              => 'DATALINE_WHERE',
        RULE_DESC              => 'Dataline to select only UeRc_13 for aggregation',
        INPUT_FILE_DESCRIPTION 	=> ['^ManagedElement_RncFunction_UeRc-#-.+-#-J\.pif$',],
        COUNTER_NAMES          => [ 
	{
        	'COUNTER_NAME'   => 'moid_UeRc',
        	'KEEP_WHERE'     => [ '^13$', ],
        	'REMOVE_WHERE'   => [],
        }
        ],
	FILENAME_ADDITION	=> 'UeRc_13',
        PRODUCE_PIF 		=> 'True',
	OUTPUT_FORMAT		=> 0,
},
# Actual aggregation of UeRc_13
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate UeRc_13 blocks',
        INPUT_FILE_DESCRIPTION 	=> ['^ManagedElement_RncFunction_UeRc-#-.+-#-J-#-UeRc_13-#-DW\.pif$',],
        COUNTERS_TO_SORT_ON    => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        NON_ADDITIVE_COUNTERS  => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UeRc_13',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UeRc_13',
        PRODUCE_PIF            => 0,
	OUTPUT_FORMAT	=> 'LIF_Writer',
},
# Remove UeRc initial PIFs 
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove UeRc initial PIFs',
        INPUT_FILE_DESCRIPTION 	=> ['^ManagedElement_RncFunction_UeRc-#-.+-#-I\.pif$',],
},
# END : UeRc

# Insert UtranCell_id from hierarchy PIF into CDMA Channel objects
# Note: The "vsDataRbsLocalCell-#-.+-#-J-#-S\.pif" file must be generated using the hierarchy parser first
{
    RULE_TYPE                           => 'INFOINSERT',
    RULE_DESC                           => 'Insert UtranCell_id from hierarchy PIF into CDMA Channel objects',
    INPUT_FILE_DESCRIPTION              => ['^ME_NodeBFunction_HsDschResources-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                            '^ManagedElement_NodeBFunction_Sector_Carrier_Aich-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                            '^ME_NodeBFunction_Sector_Carrier_EDchResources-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                            '^ME_NodeBFunction_Sector_Carrier_Prach-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                            '^ManagedElement_NodeBFunction_Carrier_Sccpch-#-.+-#-.+-#-.+-#-.+-#-I\.pif$'],
    HEADER_NAMES_USED_TO_ID_DATA_RECORD => ['nedn_MeContext'],
    NAMES_USED_TO_ID_DATA_RECORD        => ['moid_ManagedElement','moid_NodeBFunction','moid_Carrier','moid_Sector'],
    INFO_FILE_DESCRIPTION               => ['^vsDataRbsLocalCell-#-.+-#-J-#-S\.pif$'],
    HEADER_NAMES_USED_TO_ID_INFORMATION => [],
    NAMES_USED_TO_ID_INFORMATION        => ['carrierRef_MeContext','carrierRef_ManagedElement','carrierRef_NodeBFunction','carrierRef_vsDataCa
rrier','carrierRef_vsDataSector'],
    REDUNDANT_DATA_COUNTERS             => [],
    ONLY_INSERT                         => ['UtranCell_id'],
    WRITE_DATA_LINE                     => 'True',
    PRODUCE_PIF                         => 'True',
    #OUTPUT_FORMAT                       => 'LIF_Writer',
},


#APAR IZ20368
{
    RULE_TYPE               => 'BATCHFILES',
    RULE_DESC               => 'Batch ME_NodeBFunction HsDschResources pif files',
    INPUT_FILE_DESCRIPTION  => ['^ME_NodeBFunction_HsDschResources-#-.+-#-.+-#-.+-#-.+-#-I-#-S\.pif'],
    PRODUCE_PIF => 'True',
#    OUTPUT_FORMAT => 'LIF_Writer',
    OUTPUT_FILENAME_START => 'BATCHED_ME_NodeBFunction_HsDschResources',
},


# JOIN UtranCell files
{
        RULE_TYPE              => 'JOIN',
        RULE_DESC              => 'Join of UtranCell files',
        INPUT_FILE_DESCRIPTION 	=> [
				'^ManagedElement_RncFunction_UtranCell-#-(.+)-#-\d+-#-I\.pif$',
				'^ManagedElement_RncFunction_UtranCell_Rach-#-(.+)-#-\d+-#-I\.pif$',
				],
	COUNTERS_TO_JOIN_ON    => ['nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement', 'moid_RncFunction', 'moid_UtranCell'],
	HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UtranCell',
	OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UtranCell',
	HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_SubNetwork', 'nedn_MeContext','mts'],
        PRODUCE_PIF            => 'True',
#	OUTPUT_FORMAT	=> 'LIF_Writer',
},

#### the insert into the traffict data the required counters
{
        RULE_TYPE               => 'INFOINSERT',
        RULE_DESC               => 'INFOINSERT HSpeed data',
        INPUT_FILE_DESCRIPTION  => ['ManagedElement_RncFunction_UtranCell-#-.+-#-J'],
        HEADER_NAMES_USED_TO_ID_DATA_RECORD => ['nedn_SubNetwork'],
        NAMES_USED_TO_ID_DATA_RECORD => ['moid_UtranCell','mts'],
        INFO_FILE_DESCRIPTION   => ['BATCHED_ME_NodeBFunction_HsDschResources-#-.+-#-BF\.pif'],
        HEADER_NAMES_USED_TO_ID_INFORMATION => ['nedn_SubNetwork'],
        NAMES_USED_TO_ID_INFORMATION => ['moid_UtranCell','mts'],
        OUTPUT_BLOCK_NAME       => 'ManagedElement_RncFunction_UtranCell',
        #OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UtranCell',
        REDUNDANT_DATA_COUNTERS => [],
        ONLY_INSERT             => ['pmSumTransmittedBits'],
        WRITE_DATA_LINE         => 'True',
        PRODUCE_PIF             => 'True',
        PRODUCE_LIF             => 0,
},


#### JOIN any other required measurements ####
#### Finally add up the total_traffic calculation ###
 {
         RULE_TYPE              => 'PERLIZE',
         RULE_DESC              => 'Calculate Total Traffic value',
         INPUT_FILE_DESCRIPTION => [ '^ManagedElement_RncFunction_UtranCell-#-.+-#-(J|J-#-S)\.pif$'],
         DEFAULT_NULL_VALUE     => 'NULL',
         DATA_COUNTERS_OP => sub {
             my ($h_ref) = @_;
             my $hsdpa_val = $h_ref->{pmSumTransmittedBits};
             my $tot_traff = $h_ref->{pmUlTrafficVolumeCs12} + $h_ref->{pmUlTrafficVolumeCs57} + $h_ref->{pmUlTrafficVolumeCs64} + $h_ref->{pmUlTrafficVolumePs64} + $h_ref->{pmUlTrafficVolumePs128}  + $h_ref->{pmUlTrafficVolumePs384} + $h_ref->{pmUlTrafficVolumePsCommon}  + $h_ref->{pmDlTrafficVolumeCs12} +  $h_ref->{pmDlTrafficVolumeCs57} + $h_ref->{pDlTrafficVolumeCs64} + $h_ref->{pmDlTrafficVolumePs64} + $h_ref->{pmDlTrafficVolumePs128} + $h_ref->{pmDlTrafficVolumePs384} + $h_ref->{pmDlTrafficVolumePsCommon};
             if (defined $hsdpa_val ) {
               $tot_traff = ($tot_traff + $h_ref->{pmSumTransmittedBits});
            }
           $h_ref->{total_traffic} = $tot_traff;

         # all okay
         return 0;
         },

        FILENAME_SUFFIX        => 'MO',
        PRODUCE_PIF            => 'True',
        OUTPUT_FORMAT          => 'LIF_Writer',
  },

# Aggregation of UtranCell files to RNC level
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate UtranCell blocks',
        INPUT_FILE_DESCRIPTION 	=> ['^ManagedElement_RncFunction_UtranCell-#-.+-#-J\.pif$'],
        COUNTERS_TO_SORT_ON    => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        NON_ADDITIVE_COUNTERS  => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UtranCell',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UtranCell',
        PRODUCE_PIF            => 'True',
	OUTPUT_FORMAT	=> 0,
},
# Remove joined UtranCell and accumulated PIFs 
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove joined UtranCell initial PIFs',
        INPUT_FILE_DESCRIPTION 	=> [
				'^ManagedElement_RncFunction_UtranCell-#-(.+)-#-\d+-#-I\.pif$',
				'^ManagedElement_RncFunction_UtranCell_Rach-#-(.+)-#-\d+-#-I\.pif$',
				'^ManagedElement_RncFunction_UtranCell-#-.+-#-J\.pif$',
				],
},
# JOIN RncFunction files
{
        RULE_TYPE              => 'JOIN',
        RULE_DESC              => 'Join of RncFunction files',
        INPUT_FILE_DESCRIPTION 	=> [
				'^ManagedElement_RncFunction-#-(.+)-#-\d+-#-I\.pif$',
				#'^ManagedElement_RncFunction_CchFrameSynch-#-(.+)-#-\d+-#-I\.pif$',
				#'^ManagedElement_RncFunction_DchFrameSynch-#-(.+)-#-\d+-#-I\.pif$',
				'^ManagedElement_RncFunction_UePositioning-#-(.+)-#-\d+-#-I\.pif$',
				'^ManagedElement_RncFunction_UtranCell-#-(.+)-#-\d+-#-J-#-ManagedElement_RncFunction_UtranCell-#-A\.pif$',
				],
	COUNTERS_TO_JOIN_ON    => ['nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement', 'moid_RncFunction'],
	HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction',
	OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction',
	HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_SubNetwork', 'nedn_MeContext','mts'],
        PRODUCE_PIF            => 0,
	OUTPUT_FORMAT	=> 'LIF_Writer',
},


# Remove joined RncFunction initial PIFs 
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove joined RncFunction initial PIFs',
        INPUT_FILE_DESCRIPTION 	=> [
				'^ManagedElement_RncFunction-#-(.+)-#-\d+-#-I\.pif$',
				#'^ManagedElement_RncFunction_CchFrameSynch-#-(.+)-#-\d+-#-I\.pif$',
				#'^ManagedElement_RncFunction_DchFrameSynch-#-(.+)-#-\d+-#-I\.pif$',
				'^ManagedElement_RncFunction_UePositioning-#-(.+)-#-\d+-#-I\.pif$',
				'^ManagedElement_RncFunction_UtranCell-#-(.+)-#-\d+-#-J-#-ManagedElement_RncFunction_UtranCell-#-A\.pif$',
				],
},

# START : NodeB_DLBasebandPool
# Aggregation of pmApomcOfSpreadersUsed counter
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate NodeB_DLBasebandPool blocks',
        INPUT_FILE_DESCRIPTION 	=> ['^NodeB_DLBasebandPool-#-.+-#-\d+-#-I\.pif$',], 
        COUNTERS_TO_SORT_ON    => ['moid_ManagedElement','moid_Equipment','moid_Subrack','moid_DownlinkBaseBandPool','mts'],
        NON_ADDITIVE_COUNTERS  => ['moid_ManagedElement','moid_Equipment','moid_Subrack','moid_DownlinkBaseBandPool','mts'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'Group_ManagedElement',
        OUTPUT_FILENAME_START  => 'Group_ManagedElement',
        AVERAGE_COUNTERS       => ['pmApomcOfSpreadersUsed'],
        AVERAGE_APPEND_STR     => "_AVG",
        AVERAGE_NO_APPEND_STR  => ['pmApomcOfSpreadersUsed'],
        PRODUCE_PIF            => 'True',
        #OUTPUT_FORMAT          => 'LIF_Writer',
},
# END : NodeB_DLBasebandPool


#----------------------------------------


# Unpegger for RNC_AAL2_SP
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg RNC_AAL2_SP Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_AAL2_SP-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_AAL2_SP-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Aal2Sp'],
        DEFAULT_NULL_VALUE         => 'NULL',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT              => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        MAX_PEG_PIF_AGE            => '3600',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
             'pmUnsuccessfulConnsInternal' => 4294967295,
        },
},
# Remove initial PIF after unpegger for RNC_AAL2_SP
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial RNC_AAL2_SP PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_AAL2_SP-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : RNC_AAL2_SP



# Join all ME_NodeBFunction_HsDschResources PIF files into one single PIF file
# This is needed if hierarchy info file exists
{   
    RULE_TYPE                  => 'JOIN',
    RULE_DESC                  => 'Join all ME_NodeBFunction_HsDschResources PIF files into one single PIF file',
    INPUT_FILE_DESCRIPTION     => [ '^(ME_NodeBFunction_HsDschResources-#-.+-#-.+-#-.+-#-.+-#)-(I|I-#-S)\.pif$' ],
    COUNTERS_TO_JOIN_ON        => [ qw( moid_ManagedElement moid_NodeBFunction moid_Carrier moid_Sector ) ],
    HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
    OUTPUT_FILENAME_START      => 'ME_NodeBFunction_HsDschResources',
    HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_SubNetwork', 'nedn_MeContext','mts'],
    OUTPUT_BLOCK_NAME          => 'ME_NodeBFunction_HsDschResources',
    PRODUCE_PIF                => 'True',
},

# Join all ManagedElement_NodeBFunction_Sector_Carrier_Aich PIF files into one single PIF file
# This is needed if hierarchy info file exists
{   
    RULE_TYPE                  => 'JOIN',
    RULE_DESC                  => 'Join all ManagedElement_NodeBFunction_Sector_Carrier_Aich PIF files into one single PIF file',
    INPUT_FILE_DESCRIPTION     => [ '^(ManagedElement_NodeBFunction_Sector_Carrier_Aich-#-.+-#-.+-#-.+-#-.+-#)-(I|I-#-S)\.pif$' ],
    COUNTERS_TO_JOIN_ON        => [ qw( moid_ManagedElement moid_NodeBFunction moid_Carrier moid_Sector ) ],
    HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
    OUTPUT_FILENAME_START      => 'ManagedElement_NodeBFunction_Sector_Carrier_Aich',
    HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_SubNetwork', 'nedn_MeContext','mts'],
    OUTPUT_BLOCK_NAME          => 'ManagedElement_NodeBFunction_Sector_Carrier_Aich',
    PRODUCE_PIF                => 'True',
},

# Join all ME_NodeBFunction_Sector_Carrier_EDchResources PIF files into one single PIF file
# This is needed if hierarchy info file exists
{   
    RULE_TYPE                  => 'JOIN',
    RULE_DESC                  => 'Join all ME_NodeBFunction_Sector_Carrier_EDchResources PIF files into one single PIF file',
    INPUT_FILE_DESCRIPTION     => [ '^(ME_NodeBFunction_Sector_Carrier_EDchResources-#-.+-#-.+-#-.+-#-.+-#)-(I|I-#-S)\.pif$' ],
    COUNTERS_TO_JOIN_ON        => [ qw( moid_ManagedElement moid_NodeBFunction moid_Carrier moid_Sector ) ],
    HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
    OUTPUT_FILENAME_START      => 'ME_NodeBFunction_Sector_Carrier_EDchResources',
    HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_SubNetwork', 'nedn_MeContext','mts'],
    OUTPUT_BLOCK_NAME          => 'ME_NodeBFunction_Sector_Carrier_EDchResources',
    PRODUCE_PIF                => 'True',
},

# Join all ME_NodeBFunction_Sector_Carrier_Prach PIF files into one single PIF file
# This is needed if hierarchy info file exists
{   
    RULE_TYPE                  => 'JOIN',
    RULE_DESC                  => 'Join all ME_NodeBFunction_Sector_Carrier_Prach PIF files into one single PIF file',
    INPUT_FILE_DESCRIPTION     => [ '^(ME_NodeBFunction_Sector_Carrier_Prach-#-.+-#-.+-#-.+-#-.+-#)-(I|I-#-S)\.pif$' ],
    COUNTERS_TO_JOIN_ON        => [ qw( moid_ManagedElement moid_NodeBFunction moid_Carrier moid_Sector ) ],
    HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
    OUTPUT_FILENAME_START      => 'ME_NodeBFunction_Sector_Carrier_Prach',
    HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_SubNetwork', 'nedn_MeContext','mts'],
    OUTPUT_BLOCK_NAME          => 'ME_NodeBFunction_Sector_Carrier_Prach',
    PRODUCE_PIF                => 'True',
},

# Join all ManagedElement_NodeBFunction_Carrier_Sccpch PIF files into one single PIF file
# This is needed if hierarchy info file exists
{   
    RULE_TYPE                  => 'JOIN',
    RULE_DESC                  => 'Join all ManagedElement_NodeBFunction_Carrier_Sccpch PIF files into one single PIF file',
    INPUT_FILE_DESCRIPTION     => [ '^(ManagedElement_NodeBFunction_Carrier_Sccpch-#-.+-#-.+-#-.+-#-.+-#)-(I|I-#-S)\.pif$' ],
    COUNTERS_TO_JOIN_ON        => [ qw( moid_ManagedElement moid_NodeBFunction moid_Carrier moid_Sector ) ],
    HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
    OUTPUT_FILENAME_START      => 'ManagedElement_NodeBFunction_Carrier_Sccpch',
    HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_SubNetwork', 'nedn_MeContext','mts'],
    OUTPUT_BLOCK_NAME          => 'ManagedElement_NodeBFunction_Carrier_Sccpch',
    PRODUCE_PIF                => 'True',
},

# Batch files for the following blocks
{
    RULE_TYPE               => 'BATCHFILES' ,
    RULE_DESC               => 'Batch files for the following blocks',
    INPUT_FILE_DESCRIPTION  => ['^(UNPEG-#-NODEB_ATM_Physical_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-RXI_ATM_Physical_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_Virtual_Channel_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-RXI_Virtual_Channel_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_Virtual_Path_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-RXI_Virtual_Path_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(NodeB_DLBasebandPool)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^NodeB_DLBasebandPool-#-.+-#-.+-#-.+-#-.+-#-I-#-(Group_ManagedElement)-#-A\.pif$',                                
                                '^(ME_NodeBFunction_IubDataStreams)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ME_NodeBFunction_RbsLocalCell_Carrier)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(NodeB_ULBasebandPool)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(NODEB_AAL2_AP)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ME_NodeBFunction_HsDschResources)-#-.+-#-.+-#-.+-#-.+-#-J\.pif$',
                                '^(ManagedElement_NodeBFunction_Sector_Carrier_Aich)-#-.+-#-.+-#-.+-#-.+-#-I-#-S\.pif$',
                                '^(ME_NodeBFunction_Sector_Carrier_EDchResources)-#-.+-#-.+-#-.+-#-.+-#-J\.pif$',
                                '^(ME_NodeBFunction_Sector_Carrier_Prach)-#-.+-#-.+-#-.+-#-.+-#-J\.pif$',
                                '^(ManagedElement_NodeBFunction_Carrier_Sccpch)-#-.+-#-.+-#-.+-#-.+-#-J\.pif$',
                                '^(NODEB_AAL2_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(NODEB_AAL2_SP)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(NODEB_E1_T1_J1_PHYSICAL_LINK)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_IMA_GROUP)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_IMA_LINK)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_Virtual_Path_Connection)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_UniSAalTp_Signaling)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_IP_ATM_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_IP_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_IpSystem_IpAccessHostGpb)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_IpSystem_IpAccessUdpHostMsb)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_Mtp2tpItu)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_NniSAalTp_Signaling)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_Ospf)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_OspfArea)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_OspfInterface)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_SCTP)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ME_NodeBFunction_Carrier_RadioLinks)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ME_NodeBFunction_NbapCommon)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_NodeBFunction_Iub)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ME_Eqpt_Subrack_Slot_PlugInUnit_SpbDvGrp_CcDevice)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ME_Eqpt_Subrack_Slot_PlugInUnit_SpbDvGrp_DcDevice)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ME_RNC_IubLink_IubEdch)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ME_RncFunction_LocationArea_RoutingArea)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ME_RncFunction_RncModule_PacketDataRouter)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_CchFrameSynch)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_DchFrameSynch)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_IubLink)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_IurLink)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_LocationArea)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_NbapCommon)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_Paging)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_PdrDevice)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_Rcs)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_SecurityHandling)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_UtranCell)-#-.+-#-.+-#-.+-#-.+-#-J\.pif$',
                                '^(ManagedElement_RncFunction_UtranCell_Hsdsch)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_UtranCell_Hsdsch_Eul)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(RNC_155_Physical_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(RNC_AAL2_AP)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(RNC_AAL2_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(RNC_PIU_GeneralProcessorUnit_LoadControl)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(RNC_VC4)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-RNC_Virtual_Path_Link-#-RBNF1E)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',],
    OUTPUT_FORMAT           => 'LIF_Writer',
    PRODUCE_PIF             => 0,
    OUTPUT_FILENAME_START   => 'BATCHED',
},

# Remove batched PIF files
{
    RULE_TYPE               => 'PIF_REMOVE',
    RULE_DESC               => 'Remove batched PIF files',
    INPUT_FILE_DESCRIPTION  => ['^(UNPEG-#-NODEB_ATM_Physical_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-RXI_ATM_Physical_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_Virtual_Channel_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-RXI_Virtual_Channel_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_Virtual_Path_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-RXI_Virtual_Path_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(NodeB_DLBasebandPool)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(NodeB_DLBasebandPool)-#-.+-#-.+-#-.+-#-.+-#-I-#-Group_ManagedElement-#-A\.pif$',                                
                                '^(ME_NodeBFunction_IubDataStreams)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ME_NodeBFunction_RbsLocalCell_Carrier)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(NodeB_ULBasebandPool)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(NODEB_AAL2_AP)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ME_NodeBFunction_HsDschResources)-#-.+-#-.+-#-.+-#-.+-#-J\.pif$',
                                '^(ME_NodeBFunction_HsDschResources-#-.+-#-.+-#-.+-#-.+-#)-(I|I-#-S)\.pif$',
                                '^(ManagedElement_NodeBFunction_Sector_Carrier_Aich)-#-.+-#-.+-#-.+-#-.+-#-J\.pif$',
                                '^(ManagedElement_NodeBFunction_Sector_Carrier_Aich-#-.+-#-.+-#-.+-#-.+-#)-(I|I-#-S)\.pif$',
                                '^(ME_NodeBFunction_Sector_Carrier_EDchResources)-#-.+-#-.+-#-.+-#-.+-#-J\.pif$',
                                '^(ME_NodeBFunction_Sector_Carrier_EDchResources-#-.+-#-.+-#-.+-#-.+-#)-(I|I-#-S)\.pif$',
                                '^(ME_NodeBFunction_Sector_Carrier_Prach)-#-.+-#-.+-#-.+-#-.+-#-J\.pif$',
                                '^(ME_NodeBFunction_Sector_Carrier_Prach-#-.+-#-.+-#-.+-#-.+-#)-(I|I-#-S)\.pif$',
                                '^(ManagedElement_NodeBFunction_Carrier_Sccpch)-#-.+-#-.+-#-.+-#-.+-#-J\.pif$',
                                '^(ManagedElement_NodeBFunction_Carrier_Sccpch-#-.+-#-.+-#-.+-#-.+-#)-(I|I-#-S)\.pif$',
                                '^(NODEB_AAL2_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(NODEB_AAL2_SP)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(NODEB_E1_T1_J1_PHYSICAL_LINK)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_IMA_GROUP)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_IMA_LINK)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_Virtual_Path_Connection)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_UniSAalTp_Signaling)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_IP_ATM_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_IP_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_IpSystem_IpAccessHostGpb)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_IpSystem_IpAccessUdpHostMsb)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_Mtp2tpItu)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_NniSAalTp_Signaling)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_Ospf)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_OspfArea)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_OspfInterface)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-NODEB_SCTP)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ME_NodeBFunction_Carrier_RadioLinks)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ME_NodeBFunction_NbapCommon)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_NodeBFunction_Iub)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ME_Eqpt_Subrack_Slot_PlugInUnit_SpbDvGrp_CcDevice)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ME_Eqpt_Subrack_Slot_PlugInUnit_SpbDvGrp_DcDevice)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ME_RNC_IubLink_IubEdch)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ME_RncFunction_LocationArea_RoutingArea)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ME_RncFunction_RncModule_PacketDataRouter)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_CchFrameSynch)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_DchFrameSynch)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_IubLink)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_IurLink)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_LocationArea)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_NbapCommon)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_Paging)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_PdrDevice)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_Rcs)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_SecurityHandling)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_UtranCell)-#-.+-#-.+-#-.+-#-.+-#-J\.pif$',
                                '^(ManagedElement_RncFunction_UtranCell_Hsdsch)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ManagedElement_RncFunction_UtranCell_Hsdsch_Eul)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(RNC_155_Physical_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(RNC_AAL2_AP)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(RNC_AAL2_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(RNC_PIU_GeneralProcessorUnit_LoadControl)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(RNC_VC4)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(UNPEG-#-RNC_Virtual_Path_Link-#-RBNF1E)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',],
},

# Output all initial PIFs
{
    RULE_TYPE               => 'PIF_2_OUTPUT',
    RULE_DESC               => 'Output all unprocessed initial PIF files',
    INPUT_FILE_DESCRIPTION  => '^(?!SAVED-#-?).+-#-I\.pif$',
    PRODUCE_PIF             => 0,
    OUTPUT_FORMAT           => 'LIF_Writer',
},

);

#------------------------------------------------------------------------------------------------

sub postparser_config {
	return \@rules;
}

1;

